==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/ctimer.h <==
/***************************************************************************
                          ctimer.h  -  description
                             -------------------
    begin                : ?t mj 8 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTIMER_H
#define CTIMER_H

#include <qwidget.h>

#include "csaveablefield.h"

class cSession;

/**
One timer.
  *@author Tomas Mecir
  */

class cTimer : public cSaveableField  {
   Q_OBJECT
public:
  cTimer (cSession *s);
  virtual ~cTimer ();

  /** creates a new instance of the class */
  virtual cSaveableField *newInstance ();

  virtual QString performAction ();
  virtual void tick (int tickTime);
  void resetTickCount ();

  virtual bool shouldContinue (bool) { return false; };

  /** load data from a config file*/
  virtual void load (KConfig *config, const QString &group);
  /** save data to a config file*/
  virtual void save (KConfig *config, const QString &group);

  /** returns type of item (light-weight RTTI) */
  virtual int itemType () { return TYPE_TIMER; };

  void setInterval (int what);
  int interval () { return _interval; };
  void setSingleShot (bool what) { _singleshot = what; };
  bool singleShot () { return _singleshot; };
  void setActive (bool what) { _active = what; };
  bool active () { return _active; };
  void setCommand (const QString &what) { _command = what; };
  const QString &command () { return _command; };
  /** should this timer be deleted? True if this is a one-shot timer that
  was already executed */
  bool shouldDelete () { return _shoulddelete; };
protected:
  int _interval;
 
  bool _singleshot, _active;
  bool _shoulddelete;
  QString _command;

  int _nextlaunch;
  cSession *sess;
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/ctimer.h <==
/***************************************************************************
                          ctimer.h  -  description
                             -------------------
    begin                : St maj 8 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTIMER_H
#define CTIMER_H

#include <qwidget.h>

#include "csaveablefield.h"

/**
One timer.
  *@author Tomas Mecir
  */

class cTimer : public cSaveableField  {
   Q_OBJECT
public:
  cTimer (int _sess);
  virtual ~cTimer ();

  /** creates a new instance of the class */
  virtual cSaveableField *newInstance ();

  virtual QString performAction ();
  virtual void tick (int tickTime);
  void resetTickCount ();

  virtual bool shouldContinue (bool) { return false; };

  /** load data from a config file*/
  virtual void load (KConfig *config, const QString &group);
  /** save data to a config file*/
  virtual void save (KConfig *config, const QString &group);

  /** returns type of item (light-weight RTTI) */
  virtual int itemType () { return TYPE_TIMER; };

  void setInterval (int what);
  int interval () { return _interval; };
  void setSingleShot (bool what) { _singleshot = what; };
  bool singleShot () { return _singleshot; };
  void setActive (bool what) { _active = what; };
  bool active () { return _active; };
  void setCommand (const QString &what) { _command = what; };
  const QString &command () { return _command; };
  /** should this timer be deleted? True if this is a one-shot timer that
  was already executed */
  bool shouldDelete () { return _shoulddelete; };
protected:
  int _interval;
 
  bool _singleshot, _active;
  bool _shoulddelete;
  QString _command;

  int _nextlaunch;
  int sess;
};

#endif
